# Changelog

## [0.5.1](https://github.com/CQCL/tket2/compare/tket-eccs-v0.5.0...tket-eccs-v0.5.1) (2025-08-18)


### Documentation

* Update README badges ([#1004](https://github.com/CQCL/tket2/issues/1004)) ([d609bf5](https://github.com/CQCL/tket2/commit/d609bf5f65af3cfe3ac44a16dfd4ef1bcacd5643))

## [0.5.0](https://github.com/CQCL/tket2/compare/tket-eccs-v0.4.0...tket-eccs-v0.5.0) (2025-07-29)


### ⚠ BREAKING CHANGES

* Renamed the `tket2.*` HUGR extensions to `tket.*`
* Libraries renamed from `tket2*` to `tket*`

### Features

* Rename `tket2.*` HUGR extensions to `tket.*` ([#988](https://github.com/CQCL/tket2/issues/988)) ([c5279c5](https://github.com/CQCL/tket2/commit/c5279c55c1287980ff18c0bfdf360f69be5f345f))
* Rename tket2* libs to tket* ([#987](https://github.com/CQCL/tket2/issues/987)) ([450f06a](https://github.com/CQCL/tket2/commit/450f06ae6b2d7472ad33418299479709e307919c))

## [0.4.0](https://github.com/CQCL/tket2/compare/tket2-eccs-v0.3.0...tket2-eccs-v0.4.0) (2025-05-16)


### ⚠ BREAKING CHANGES

* bump to hugr 0.20

### Miscellaneous Chores

* Bump to hugr-0.20 ([#862](https://github.com/CQCL/tket2/issues/862)) ([652a7d0](https://github.com/CQCL/tket2/commit/652a7d0b039bca62407f16f7548204e97f92ef5a))

## [0.3.0](https://github.com/CQCL/tket2/compare/tket2-eccs-v0.2.0...tket2-eccs-v0.3.0) (2024-12-16)


### ⚠ BREAKING CHANGES

* Updated `hugr` rust dependency to `0.14.0`. The bundled ECC sets are now compatible with `hugr 0.10`.


### Miscellaneous Chores

* Update to next version of hugr ([#720](https://github.com/CQCL/tket2/issues/720)) ([4a3a5a5](https://github.com/CQCL/tket2/commit/4a3a5a5e38252d4ee709e7e97bb5a1e90bd9fff4))

## [0.2.0](https://github.com/CQCL/tket2/compare/tket2-eccs-v0.1.0...tket2-eccs-v0.2.0) (2024-10-10)


### ⚠ BREAKING CHANGES

* Recompiled eccs with `hugr 0.13.0`

## 0.1.0 (2024-08-01)


### Features

* Move the compiled eccs to a separate package ([#517](https://github.com/CQCL/tket2/issues/517)) ([7247cc6](https://github.com/CQCL/tket2/commit/7247cc65f4c4e679fd5b680d1e53e630f06d94a1))

## Changelog
